# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: protos/logicmodule.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import logicmodule_messages_pb2 as protos_dot_logicmodule__messages__pb2
from . import common_messages_pb2 as protos_dot_common__messages__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18protos/logicmodule.proto\x12\x12protos.logicmodule\x1a!protos/logicmodule_messages.proto\x1a\x1cprotos/common_messages.proto2\xb5[\n\x0bLogicModule\x12[\n\x0e\x61utoregisterSL\x12).protos.logicmodule.AutoRegisterSLRequest\x1a\x1c.protos.common.ExceptionInfo\"\x00\x12i\n\x0e\x61utoregisterEE\x12).protos.logicmodule.AutoRegisterEERequest\x1a*.protos.logicmodule.AutoRegisterEEResponse\"\x00\x12q\n\x19unregisterStorageLocation\x12\x34.protos.logicmodule.UnregisterStorageLocationRequest\x1a\x1c.protos.common.ExceptionInfo\"\x00\x12{\n\x1eunregisterExecutionEnvironment\x12\x39.protos.logicmodule.UnregisterExecutionEnvironmentRequest\x1a\x1c.protos.common.ExceptionInfo\"\x00\x12I\n\ncheckAlive\x12\x1b.protos.common.EmptyMessage\x1a\x1c.protos.common.ExceptionInfo\"\x00\x12\x83\x01\n\"notifyExecutionEnvironmentShutdown\x12=.protos.logicmodule.NotifyExecutionEnvironmentShutdownRequest\x1a\x1c.protos.common.ExceptionInfo\"\x00\x12y\n\x1dnotifyStorageLocationShutdown\x12\x38.protos.logicmodule.NotifyStorageLocationShutdownRequest\x1a\x1c.protos.common.ExceptionInfo\"\x00\x12\x96\x01\n\x1d\x65xistsActiveEnvironmentsForSL\x12\x38.protos.logicmodule.ExistsActiveEnvironmentsForSLRequest\x1a\x39.protos.logicmodule.ExistsActiveEnvironmentsForSLResponse\"\x00\x12z\n\x17performSetOfNewAccounts\x12-.protos.logicmodule.PerformSetAccountsRequest\x1a..protos.logicmodule.PerformSetAccountsResponse\"\x00\x12}\n\x16performSetOfOperations\x12/.protos.logicmodule.PerformSetOperationsRequest\x1a\x30.protos.logicmodule.PerformSetOperationsResponse\"\x00\x12[\n\x0epublishAddress\x12).protos.logicmodule.PublishAddressRequest\x1a\x1c.protos.common.ExceptionInfo\"\x00\x12k\n\x11newAccountNoAdmin\x12,.protos.logicmodule.NewAccountNoAdminRequest\x1a&.protos.logicmodule.NewAccountResponse\"\x00\x12]\n\nnewAccount\x12%.protos.logicmodule.NewAccountRequest\x1a&.protos.logicmodule.NewAccountResponse\"\x00\x12\x63\n\x0cgetAccountID\x12\'.protos.logicmodule.GetAccountIDRequest\x1a(.protos.logicmodule.GetAccountIDResponse\"\x00\x12i\n\x0egetAccountList\x12).protos.logicmodule.GetAccountListRequest\x1a*.protos.logicmodule.GetAccountListResponse\"\x00\x12]\n\nnewSession\x12%.protos.logicmodule.NewSessionRequest\x1a&.protos.logicmodule.NewSessionResponse\"\x00\x12~\n\x15getInfoOfSessionForDS\x12\x30.protos.logicmodule.GetInfoOfSessionForDSRequest\x1a\x31.protos.logicmodule.GetInfoOfSessionForDSResponse\"\x00\x12\x63\n\x0cnewNamespace\x12\'.protos.logicmodule.NewNamespaceRequest\x1a(.protos.logicmodule.NewNamespaceResponse\"\x00\x12]\n\x0fremoveNamespace\x12*.protos.logicmodule.RemoveNamespaceRequest\x1a\x1c.protos.common.ExceptionInfo\"\x00\x12i\n\x0egetNamespaceID\x12).protos.logicmodule.GetNamespaceIDRequest\x1a*.protos.logicmodule.GetNamespaceIDResponse\"\x00\x12o\n\x10getNamespaceLang\x12+.protos.logicmodule.GetNamespaceLangRequest\x1a,.protos.logicmodule.GetNamespaceLangResponse\"\x00\x12u\n\x12getObjectDataSetID\x12-.protos.logicmodule.GetObjectDataSetIDRequest\x1a..protos.logicmodule.GetObjectDataSetIDResponse\"\x00\x12]\n\x0fimportInterface\x12*.protos.logicmodule.ImportInterfaceRequest\x1a\x1c.protos.common.ExceptionInfo\"\x00\x12[\n\x0eimportContract\x12).protos.logicmodule.ImportContractRequest\x1a\x1c.protos.common.ExceptionInfo\"\x00\x12\x90\x01\n\x1bgetInfoOfClassesInNamespace\x12\x36.protos.logicmodule.GetInfoOfClassesInNamespaceRequest\x1a\x37.protos.logicmodule.GetInfoOfClassesInNamespaceResponse\"\x00\x12\xa2\x01\n!getImportedClassesInfoInNamespace\x12<.protos.logicmodule.GetImportedClassesInfoInNamespaceRequest\x1a=.protos.logicmodule.GetImportedClassesInfoInNamespaceResponse\"\x00\x12{\n\x14getClassIDfromImport\x12/.protos.logicmodule.GetClassIDFromImportRequest\x1a\x30.protos.logicmodule.GetClassIDFromImportResponse\"\x00\x12\x66\n\rgetNamespaces\x12(.protos.logicmodule.GetNamespacesRequest\x1a).protos.logicmodule.GetNamespacesResponse\"\x00\x12]\n\nnewDataSet\x12%.protos.logicmodule.NewDataSetRequest\x1a&.protos.logicmodule.NewDataSetResponse\"\x00\x12Y\n\rremoveDataSet\x12(.protos.logicmodule.RemoveDataSetRequest\x1a\x1c.protos.common.ExceptionInfo\"\x00\x12\x63\n\x0cgetDataSetID\x12\'.protos.logicmodule.GetDataSetIDRequest\x1a(.protos.logicmodule.GetDataSetIDResponse\"\x00\x12{\n\x14\x63heckDataSetIsPublic\x12/.protos.logicmodule.CheckDataSetIsPublicRequest\x1a\x30.protos.logicmodule.CheckDataSetIsPublicResponse\"\x00\x12r\n\x11getPublicDataSets\x12,.protos.logicmodule.GetPublicDataSetsRequest\x1a-.protos.logicmodule.GetPublicDataSetsResponse\"\x00\x12u\n\x12getAccountDataSets\x12-.protos.logicmodule.GetAccountDataSetsRequest\x1a..protos.logicmodule.GetAccountDataSetsResponse\"\x00\x12W\n\x08newClass\x12#.protos.logicmodule.NewClassRequest\x1a$.protos.logicmodule.NewClassResponse\"\x00\x12U\n\x0bremoveClass\x12&.protos.logicmodule.RemoveClassRequest\x1a\x1c.protos.common.ExceptionInfo\"\x00\x12]\n\x0fremoveOperation\x12*.protos.logicmodule.RemoveOperationRequest\x1a\x1c.protos.common.ExceptionInfo\"\x00\x12g\n\x14removeImplementation\x12/.protos.logicmodule.RemoveImplementationRequest\x1a\x1c.protos.common.ExceptionInfo\"\x00\x12i\n\x0egetOperationID\x12).protos.logicmodule.GetOperationIDRequest\x1a*.protos.logicmodule.GetOperationIDResponse\"\x00\x12\x66\n\rgetPropertyID\x12(.protos.logicmodule.GetPropertyIDRequest\x1a).protos.logicmodule.GetPropertyIDResponse\"\x00\x12]\n\ngetClassID\x12%.protos.logicmodule.GetClassIDRequest\x1a&.protos.logicmodule.GetClassIDResponse\"\x00\x12\x63\n\x0cgetClassInfo\x12\'.protos.logicmodule.GetClassInfoRequest\x1a(.protos.logicmodule.GetClassInfoResponse\"\x00\x12`\n\x0bnewContract\x12&.protos.logicmodule.NewContractRequest\x1a\'.protos.logicmodule.NewContractResponse\"\x00\x12o\n\x18registerToPublicContract\x12\x33.protos.logicmodule.RegisterToPublicContractRequest\x1a\x1c.protos.common.ExceptionInfo\"\x00\x12\xa8\x01\n#registerToPublicContractOfNamespace\x12>.protos.logicmodule.RegisterToPublicContractOfNamespaceRequest\x1a?.protos.logicmodule.RegisterToPublicContractOfNamespaceResponse\"\x00\x12\x8a\x01\n\x19getContractIDsOfApplicant\x12\x34.protos.logicmodule.GetContractIDsOfApplicantRequest\x1a\x35.protos.logicmodule.GetContractIDsOfApplicantResponse\"\x00\x12\x87\x01\n\x18getContractIDsOfProvider\x12\x33.protos.logicmodule.GetContractIDsOfProviderRequest\x1a\x34.protos.logicmodule.GetContractIDsOfProviderResponse\"\x00\x12\xa2\x01\n%getContractIDsOfApplicantWithProvider\x12:.protos.logicmodule.GetContractsOfApplicantWithProvRequest\x1a;.protos.logicmodule.GetContractsOfApplicantWithProvResponse\"\x00\x12l\n\x0fnewDataContract\x12*.protos.logicmodule.NewDataContractRequest\x1a+.protos.logicmodule.NewDataContractResponse\"\x00\x12w\n\x1cregisterToPublicDataContract\x12\x37.protos.logicmodule.RegisterToPublicDataContractRequest\x1a\x1c.protos.common.ExceptionInfo\"\x00\x12\x96\x01\n\x1dgetDataContractIDsOfApplicant\x12\x38.protos.logicmodule.GetDataContractIDsOfApplicantRequest\x1a\x39.protos.logicmodule.GetDataContractIDsOfApplicantResponse\"\x00\x12\x93\x01\n\x1cgetDataContractIDsOfProvider\x12\x37.protos.logicmodule.GetDataContractIDsOfProviderRequest\x1a\x38.protos.logicmodule.GetDataContractIDsOfProviderResponse\"\x00\x12\xb5\x01\n*getDataContractInfoOfApplicantWithProvider\x12\x41.protos.logicmodule.GetDataContractInfoOfApplicantWithProvRequest\x1a\x42.protos.logicmodule.GetDataContractInfoOfApplicantWithProvResponse\"\x00\x12\x63\n\x0cnewInterface\x12\'.protos.logicmodule.NewInterfaceRequest\x1a(.protos.logicmodule.NewInterfaceResponse\"\x00\x12o\n\x10getInterfaceInfo\x12+.protos.logicmodule.GetInterfaceInfoRequest\x1a,.protos.logicmodule.GetInterfaceInfoResponse\"\x00\x12]\n\x0fremoveInterface\x12*.protos.logicmodule.RemoveInterfaceRequest\x1a\x1c.protos.common.ExceptionInfo\"\x00\x12\x9c\x01\n\x1fgetAllExecutionEnvironmentsInfo\x12:.protos.logicmodule.GetAllExecutionEnvironmentsInfoRequest\x1a;.protos.logicmodule.GetAllExecutionEnvironmentsInfoResponse\"\x00\x12{\n\x14getStorageLocationID\x12/.protos.logicmodule.GetStorageLocationIDRequest\x1a\x30.protos.logicmodule.GetStorageLocationIDResponse\"\x00\x12\x81\x01\n\x16getStorageLocationInfo\x12\x31.protos.logicmodule.GetStorageLocationInfoRequest\x1a\x32.protos.logicmodule.GetStorageLocationInfoResponse\"\x00\x12\x90\x01\n\x1bgetExecutionEnvironmentInfo\x12\x36.protos.logicmodule.GetExecutionEnvironmentInfoRequest\x1a\x37.protos.logicmodule.GetExecutionEnvironmentInfoResponse\"\x00\x12\x66\n\rgetObjectInfo\x12(.protos.logicmodule.GetObjectInfoRequest\x1a).protos.logicmodule.GetObjectInfoResponse\"\x00\x12u\n\x12getObjectFromAlias\x12-.protos.logicmodule.GetObjectFromAliasRequest\x1a..protos.logicmodule.GetObjectFromAliasResponse\"\x00\x12`\n\x0b\x64\x65leteAlias\x12&.protos.logicmodule.DeleteAliasRequest\x1a\'.protos.logicmodule.DeleteAliasResponse\"\x00\x12\xa5\x01\n\"getObjectsMetaDataInfoOfClassForNM\x12=.protos.logicmodule.GetObjectsMetaDataInfoOfClassForNMRequest\x1a>.protos.logicmodule.GetObjectsMetaDataInfoOfClassForNMResponse\"\x00\x12O\n\x08\x61\x64\x64\x41lias\x12#.protos.logicmodule.AddAliasRequest\x1a\x1c.protos.common.ExceptionInfo\"\x00\x12\x66\n\x14registerObjectFromGC\x12..protos.logicmodule.RegisterObjectForGCRequest\x1a\x1c.protos.common.ExceptionInfo\"\x00\x12\x61\n\x11unregisterObjects\x12,.protos.logicmodule.UnregisterObjectsRequest\x1a\x1c.protos.common.ExceptionInfo\"\x00\x12l\n\x0fregisterObjects\x12*.protos.logicmodule.RegisterObjectsRequest\x1a+.protos.logicmodule.RegisterObjectsResponse\"\x00\x12\x7f\n setDataSetIDFromGarbageCollector\x12;.protos.logicmodule.SetDataSetIDFromGarbageCollectorRequest\x1a\x1c.protos.common.ExceptionInfo\"\x00\x12o\n\x10getMetadataByOID\x12+.protos.logicmodule.GetMetadataByOIDRequest\x1a,.protos.logicmodule.GetMetadataByOIDResponse\"\x00\x12T\n\rgetNumObjects\x12\x1b.protos.common.EmptyMessage\x1a$.protos.common.GetNumObjectsResponse\"\x00\x12W\n\x0csetDataSetID\x12\'.protos.logicmodule.SetDataSetIDRequest\x1a\x1c.protos.common.ExceptionInfo\"\x00\x12]\n\nmoveObject\x12%.protos.logicmodule.MoveObjectRequest\x1a&.protos.logicmodule.MoveObjectResponse\"\x00\x12\x61\n\x11setObjectReadOnly\x12,.protos.logicmodule.SetObjectReadOnlyRequest\x1a\x1c.protos.common.ExceptionInfo\"\x00\x12\x63\n\x12setObjectReadWrite\x12-.protos.logicmodule.SetObjectReadWriteRequest\x1a\x1c.protos.common.ExceptionInfo\"\x00\x12~\n\x15\x65xecuteImplementation\x12\x30.protos.logicmodule.ExecuteImplementationRequest\x1a\x31.protos.logicmodule.ExecuteImplementationResponse\"\x00\x12~\n\x15\x65xecuteMethodOnTarget\x12\x30.protos.logicmodule.ExecuteMethodOnTargetRequest\x1a\x31.protos.logicmodule.ExecuteMethodOnTargetResponse\"\x00\x12Y\n\rgetDataClayID\x12\x1b.protos.common.EmptyMessage\x1a).protos.logicmodule.GetDataClayIDResponse\"\x00\x12\x87\x01\n\x18registerExternalDataClay\x12\x33.protos.logicmodule.RegisterExternalDataClayRequest\x1a\x34.protos.logicmodule.RegisterExternalDataClayResponse\"\x00\x12\xa9\x01\n)registerExternalDataClayOverrideAuthority\x12\x44.protos.logicmodule.RegisterExternalDataClayOverrideAuthorityRequest\x1a\x34.protos.logicmodule.RegisterExternalDataClayResponse\"\x00\x12\xab\x01\n$notifyRegistrationOfExternalDataClay\x12?.protos.logicmodule.NotifyRegistrationOfExternalDataClayRequest\x1a@.protos.logicmodule.NotifyRegistrationOfExternalDataClayResponse\"\x00\x12z\n\x17getExternalDataClayInfo\x12-.protos.logicmodule.GetExtDataClayInfoRequest\x1a..protos.logicmodule.GetExtDataClayInfoResponse\"\x00\x12~\n\x15getExternalDataclayId\x12\x30.protos.logicmodule.GetExternalDataclayIDRequest\x1a\x31.protos.logicmodule.GetExternalDataclayIDResponse\"\x00\x12~\n\x15getClassesInNamespace\x12\x30.protos.logicmodule.GetClassesInNamespaceRequest\x1a\x31.protos.logicmodule.GetClassesInNamespaceResponse\"\x00\x12\x7f\n importModelsFromExternalDataClay\x12;.protos.logicmodule.ImportModelsFromExternalDataClayRequest\x1a\x1c.protos.common.ExceptionInfo\"\x00\x12W\n\x08getStubs\x12#.protos.logicmodule.GetStubsRequest\x1a$.protos.logicmodule.GetStubsResponse\"\x00\x12\x66\n\rgetBabelStubs\x12(.protos.logicmodule.GetBabelStubsRequest\x1a).protos.logicmodule.GetBabelStubsResponse\"\x00\x12U\n\x0bregisterECA\x12&.protos.logicmodule.RegisterECARequest\x1a\x1c.protos.common.ExceptionInfo\"\x00\x12U\n\x0b\x61\x64viseEvent\x12&.protos.logicmodule.AdviseEventRequest\x1a\x1c.protos.common.ExceptionInfo\"\x00\x12g\n\x14isPrefetchingEnabled\x12\x1b.protos.common.EmptyMessage\x1a\x30.protos.logicmodule.IsPrefetchingEnabledResponse\"\x00\x12r\n\x11getClassNameForDS\x12,.protos.logicmodule.GetClassNameForDSRequest\x1a-.protos.logicmodule.GetClassNameForDSResponse\"\x00\x12\x96\x01\n\x1dgetClassNameAndNamespaceForDS\x12\x38.protos.logicmodule.GetClassNameAndNamespaceForDSRequest\x1a\x39.protos.logicmodule.GetClassNameAndNamespaceForDSResponse\"\x00\x12\x9c\x01\n\x1fgetContractIDOfDataClayProvider\x12:.protos.logicmodule.GetContractIDOfDataClayProviderRequest\x1a;.protos.logicmodule.GetContractIDOfDataClayProviderResponse\"\x00\x12\x81\x01\n\x16objectExistsInDataClay\x12\x31.protos.logicmodule.ObjectExistsInDataClayRequest\x1a\x32.protos.logicmodule.ObjectExistsInDataClayResponse\"\x00\x12W\n\x0c\x63loseSession\x12\'.protos.logicmodule.CloseSessionRequest\x1a\x1c.protos.common.ExceptionInfo\"\x00\x12~\n\x15getMetadataByOIDForDS\x12\x30.protos.logicmodule.GetMetadataByOIDForDSRequest\x1a\x31.protos.logicmodule.GetMetadataByOIDForDSResponse\"\x00\x12]\n\x0f\x61\x63tivateTracing\x12*.protos.logicmodule.ActivateTracingRequest\x1a\x1c.protos.common.ExceptionInfo\"\x00\x12P\n\x11\x64\x65\x61\x63tivateTracing\x12\x1b.protos.common.EmptyMessage\x1a\x1c.protos.common.ExceptionInfo\"\x00\x12L\n\tgetTraces\x12\x1b.protos.common.EmptyMessage\x1a .protos.common.GetTracesResponse\"\x00\x12R\n\x13\x63leanMetaDataCaches\x12\x1b.protos.common.EmptyMessage\x1a\x1c.protos.common.ExceptionInfo\"\x00\x12M\n\x0e\x63loseManagerDb\x12\x1b.protos.common.EmptyMessage\x1a\x1c.protos.common.ExceptionInfo\"\x00\x12\x46\n\x07\x63loseDb\x12\x1b.protos.common.EmptyMessage\x1a\x1c.protos.common.ExceptionInfo\"\x00\x42R\n8es.bsc.dataclay.communication.grpc.generated.logicmoduleB\x16LogicModuleGrpcServiceb\x06proto3')



_LOGICMODULE = DESCRIPTOR.services_by_name['LogicModule']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n8es.bsc.dataclay.communication.grpc.generated.logicmoduleB\026LogicModuleGrpcService'
  _LOGICMODULE._serialized_start=114
  _LOGICMODULE._serialized_end=11815
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from . import common_messages_pb2 as protos_dot_common__messages__pb2
from . import dataservice_messages_pb2 as protos_dot_dataservice__messages__pb2
from . import dataservice_pb2 as protos_dot_dataservice__pb2


class DataServiceStub(object):
    """Interface exported by the server.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.initBackendID = channel.unary_unary(
                '/protos.dataservice.DataService/initBackendID',
                request_serializer=protos_dot_dataservice__messages__pb2.InitBackendIDRequest.SerializeToString,
                response_deserializer=protos_dot_common__messages__pb2.ExceptionInfo.FromString,
                )
        self.associateExecutionEnvironment = channel.unary_unary(
                '/protos.dataservice.DataService/associateExecutionEnvironment',
                request_serializer=protos_dot_dataservice__messages__pb2.AssociateExecutionEnvironmentRequest.SerializeToString,
                response_deserializer=protos_dot_common__messages__pb2.ExceptionInfo.FromString,
                )
        self.deployMetaClasses = channel.unary_unary(
                '/protos.dataservice.DataService/deployMetaClasses',
                request_serializer=protos_dot_dataservice__messages__pb2.DeployMetaClassesRequest.SerializeToString,
                response_deserializer=protos_dot_common__messages__pb2.ExceptionInfo.FromString,
                )
        self.deployClasses = channel.unary_unary(
                '/protos.dataservice.DataService/deployClasses',
                request_serializer=protos_dot_dataservice__messages__pb2.DeployClassesRequest.SerializeToString,
                response_deserializer=protos_dot_common__messages__pb2.ExceptionInfo.FromString,
                )
        self.enrichClass = channel.unary_unary(
                '/protos.dataservice.DataService/enrichClass',
                request_serializer=protos_dot_dataservice__messages__pb2.EnrichClassRequest.SerializeToString,
                response_deserializer=protos_dot_common__messages__pb2.ExceptionInfo.FromString,
                )
        self.newPersistentInstance = channel.unary_unary(
                '/protos.dataservice.DataService/newPersistentInstance',
                request_serializer=protos_dot_dataservice__messages__pb2.NewPersistentInstanceRequest.SerializeToString,
                response_deserializer=protos_dot_dataservice__messages__pb2.NewPersistentInstanceResponse.FromString,
                )
        self.storeObjects = channel.unary_unary(
                '/protos.dataservice.DataService/storeObjects',
                request_serializer=protos_dot_dataservice__messages__pb2.StoreObjectsRequest.SerializeToString,
                response_deserializer=protos_dot_common__messages__pb2.ExceptionInfo.FromString,
                )
        self.getCopyOfObject = channel.unary_unary(
                '/protos.dataservice.DataService/getCopyOfObject',
                request_serializer=protos_dot_dataservice__messages__pb2.GetCopyOfObjectRequest.SerializeToString,
                response_deserializer=protos_dot_dataservice__messages__pb2.GetCopyOfObjectResponse.FromString,
                )
        self.updateObject = channel.unary_unary(
                '/protos.dataservice.DataService/updateObject',
                request_serializer=protos_dot_dataservice__messages__pb2.UpdateObjectRequest.SerializeToString,
                response_deserializer=protos_dot_common__messages__pb2.ExceptionInfo.FromString,
                )
        self.getObjects = channel.unary_unary(
                '/protos.dataservice.DataService/getObjects',
                request_serializer=protos_dot_dataservice__messages__pb2.GetObjectsRequest.SerializeToString,
                response_deserializer=protos_dot_dataservice__messages__pb2.GetObjectsResponse.FromString,
                )
        self.newVersion = channel.unary_unary(
                '/protos.dataservice.DataService/newVersion',
                request_serializer=protos_dot_dataservice__messages__pb2.NewVersionRequest.SerializeToString,
                response_deserializer=protos_dot_dataservice__messages__pb2.NewVersionResponse.FromString,
                )
        self.consolidateVersion = channel.unary_unary(
                '/protos.dataservice.DataService/consolidateVersion',
                request_serializer=protos_dot_dataservice__messages__pb2.ConsolidateVersionRequest.SerializeToString,
                response_deserializer=protos_dot_common__messages__pb2.ExceptionInfo.FromString,
                )
        self.upsertObjects = channel.unary_unary(
                '/protos.dataservice.DataService/upsertObjects',
                request_serializer=protos_dot_dataservice__messages__pb2.UpsertObjectsRequest.SerializeToString,
                response_deserializer=protos_dot_common__messages__pb2.ExceptionInfo.FromString,
                )
        self.newReplica = channel.unary_unary(
                '/protos.dataservice.DataService/newReplica',
                request_serializer=protos_dot_dataservice__messages__pb2.NewReplicaRequest.SerializeToString,
                response_deserializer=protos_dot_dataservice__messages__pb2.NewReplicaResponse.FromString,
                )
        self.moveObjects = channel.unary_unary(
                '/protos.dataservice.DataService/moveObjects',
                request_serializer=protos_dot_dataservice__messages__pb2.MoveObjectsRequest.SerializeToString,
                response_deserializer=protos_dot_dataservice__messages__pb2.MoveObjectsResponse.FromString,
                )
        self.removeObjects = channel.unary_unary(
                '/protos.dataservice.DataService/removeObjects',
                request_serializer=protos_dot_dataservice__messages__pb2.RemoveObjectsRequest.SerializeToString,
                response_deserializer=protos_dot_dataservice__messages__pb2.RemoveObjectsResponse.FromString,
                )
        self.migrateObjectsToBackends = channel.unary_unary(
                '/protos.dataservice.DataService/migrateObjectsToBackends',
                request_serializer=protos_dot_dataservice__messages__pb2.MigrateObjectsRequest.SerializeToString,
                response_deserializer=protos_dot_dataservice__messages__pb2.MigrateObjectsResponse.FromString,
                )
        self.getClassIDFromObjectInMemory = channel.unary_unary(
                '/protos.dataservice.DataService/getClassIDFromObjectInMemory',
                request_serializer=protos_dot_dataservice__messages__pb2.GetClassIDFromObjectInMemoryRequest.SerializeToString,
                response_deserializer=protos_dot_dataservice__messages__pb2.GetClassIDFromObjectInMemoryResponse.FromString,
                )
        self.executeImplementation = channel.unary_unary(
                '/protos.dataservice.DataService/executeImplementation',
                request_serializer=protos_dot_dataservice__messages__pb2.ExecuteImplementationRequest.SerializeToString,
                response_deserializer=protos_dot_dataservice__messages__pb2.ExecuteImplementationResponse.FromString,
                )
        self.makePersistent = channel.unary_unary(
                '/protos.dataservice.DataService/makePersistent',
                request_serializer=protos_dot_dataservice__messages__pb2.OldMakePersistentRequest.SerializeToString,
                response_deserializer=protos_dot_common__messages__pb2.ExceptionInfo.FromString,
                )
        self.federate = channel.unary_unary(
                '/protos.dataservice.DataService/federate',
                request_serializer=protos_dot_dataservice__messages__pb2.FederateRequest.SerializeToString,
                response_deserializer=protos_dot_common__messages__pb2.ExceptionInfo.FromString,
                )
        self.unfederate = channel.unary_unary(
                '/protos.dataservice.DataService/unfederate',
                request_serializer=protos_dot_dataservice__messages__pb2.UnfederateRequest.SerializeToString,
                response_deserializer=protos_dot_common__messages__pb2.ExceptionInfo.FromString,
                )
        self.notifyFederation = channel.unary_unary(
                '/protos.dataservice.DataService/notifyFederation',
                request_serializer=protos_dot_dataservice__messages__pb2.NotifyFederationRequest.SerializeToString,
                response_deserializer=protos_dot_common__messages__pb2.ExceptionInfo.FromString,
                )
        self.notifyUnfederation = channel.unary_unary(
                '/protos.dataservice.DataService/notifyUnfederation',
                request_serializer=protos_dot_dataservice__messages__pb2.NotifyUnfederationRequest.SerializeToString,
                response_deserializer=protos_dot_common__messages__pb2.ExceptionInfo.FromString,
                )
        self.exists = channel.unary_unary(
                '/protos.dataservice.DataService/exists',
                request_serializer=protos_dot_dataservice__messages__pb2.ExistsRequest.SerializeToString,
                response_deserializer=protos_dot_dataservice__messages__pb2.ExistsResponse.FromString,
                )
        self.synchronize = channel.unary_unary(
                '/protos.dataservice.DataService/synchronize',
                request_serializer=protos_dot_dataservice__messages__pb2.SynchronizeRequest.SerializeToString,
                response_deserializer=protos_dot_common__messages__pb2.ExceptionInfo.FromString,
                )
        self.storeToDB = channel.unary_unary(
                '/protos.dataservice.DataService/storeToDB',
                request_serializer=protos_dot_dataservice__messages__pb2.StoreToDBRequest.SerializeToString,
                response_deserializer=protos_dot_common__messages__pb2.ExceptionInfo.FromString,
                )
        self.getFromDB = channel.unary_unary(
                '/protos.dataservice.DataService/getFromDB',
                request_serializer=protos_dot_dataservice__messages__pb2.GetFromDBRequest.SerializeToString,
                response_deserializer=protos_dot_dataservice__messages__pb2.GetFromDBResponse.FromString,
                )
        self.updateToDB = channel.unary_unary(
                '/protos.dataservice.DataService/updateToDB',
                request_serializer=protos_dot_dataservice__messages__pb2.UpdateToDBRequest.SerializeToString,
                response_deserializer=protos_dot_common__messages__pb2.ExceptionInfo.FromString,
                )
        self.deleteToDB = channel.unary_unary(
                '/protos.dataservice.DataService/deleteToDB',
                request_serializer=protos_dot_dataservice__messages__pb2.DeleteToDBRequest.SerializeToString,
                response_deserializer=protos_dot_common__messages__pb2.ExceptionInfo.FromString,
                )
        self.deleteSetFromDB = channel.unary_unary(
                '/protos.dataservice.DataService/deleteSetFromDB',
                request_serializer=protos_dot_dataservice__messages__pb2.DeleteSetFromDBRequest.SerializeToString,
                response_deserializer=protos_dot_common__messages__pb2.ExceptionInfo.FromString,
                )
        self.existsInDB = channel.unary_unary(
                '/protos.dataservice.DataService/existsInDB',
                request_serializer=protos_dot_dataservice__messages__pb2.ExistsInDBRequest.SerializeToString,
                response_deserializer=protos_dot_dataservice__messages__pb2.ExistsInDBResponse.FromString,
                )
        self.cleanExecutionClassDirectory = channel.unary_unary(
                '/protos.dataservice.DataService/cleanExecutionClassDirectory',
                request_serializer=protos_dot_common__messages__pb2.EmptyMessage.SerializeToString,
                response_deserializer=protos_dot_common__messages__pb2.ExceptionInfo.FromString,
                )
        self.closeDbHandler = channel.unary_unary(
                '/protos.dataservice.DataService/closeDbHandler',
                request_serializer=protos_dot_common__messages__pb2.EmptyMessage.SerializeToString,
                response_deserializer=protos_dot_common__messages__pb2.ExceptionInfo.FromString,
                )
        self.shutDown = channel.unary_unary(
                '/protos.dataservice.DataService/shutDown',
                request_serializer=protos_dot_common__messages__pb2.EmptyMessage.SerializeToString,
                response_deserializer=protos_dot_common__messages__pb2.ExceptionInfo.FromString,
                )
        self.disconnectFromOthers = channel.unary_unary(
                '/protos.dataservice.DataService/disconnectFromOthers',
                request_serializer=protos_dot_common__messages__pb2.EmptyMessage.SerializeToString,
                response_deserializer=protos_dot_common__messages__pb2.ExceptionInfo.FromString,
                )
        self.registerPendingObjects = channel.unary_unary(
                '/protos.dataservice.DataService/registerPendingObjects',
                request_serializer=protos_dot_common__messages__pb2.EmptyMessage.SerializeToString,
                response_deserializer=protos_dot_common__messages__pb2.ExceptionInfo.FromString,
                )
        self.cleanCaches = channel.unary_unary(
                '/protos.dataservice.DataService/cleanCaches',
                request_serializer=protos_dot_common__messages__pb2.EmptyMessage.SerializeToString,
                response_deserializer=protos_dot_common__messages__pb2.ExceptionInfo.FromString,
                )
        self.activateTracing = channel.unary_unary(
                '/protos.dataservice.DataService/activateTracing',
                request_serializer=protos_dot_dataservice__messages__pb2.ActivateTracingRequest.SerializeToString,
                response_deserializer=protos_dot_common__messages__pb2.ExceptionInfo.FromString,
                )
        self.deactivateTracing = channel.unary_unary(
                '/protos.dataservice.DataService/deactivateTracing',
                request_serializer=protos_dot_common__messages__pb2.EmptyMessage.SerializeToString,
                response_deserializer=protos_dot_common__messages__pb2.ExceptionInfo.FromString,
                )
        self.getTraces = channel.unary_unary(
                '/protos.dataservice.DataService/getTraces',
                request_serializer=protos_dot_common__messages__pb2.EmptyMessage.SerializeToString,
                response_deserializer=protos_dot_common__messages__pb2.GetTracesResponse.FromString,
                )
        self.deleteAlias = channel.unary_unary(
                '/protos.dataservice.DataService/deleteAlias',
                request_serializer=protos_dot_dataservice__messages__pb2.DeleteAliasRequest.SerializeToString,
                response_deserializer=protos_dot_common__messages__pb2.ExceptionInfo.FromString,
                )
        self.detachObjectFromSession = channel.unary_unary(
                '/protos.dataservice.DataService/detachObjectFromSession',
                request_serializer=protos_dot_dataservice__messages__pb2.DetachObjectFromSessionRequest.SerializeToString,
                response_deserializer=protos_dot_common__messages__pb2.ExceptionInfo.FromString,
                )
        self.closeSessionInDS = channel.unary_unary(
                '/protos.dataservice.DataService/closeSessionInDS',
                request_serializer=protos_dot_dataservice__messages__pb2.CloseSessionInDSRequest.SerializeToString,
                response_deserializer=protos_dot_common__messages__pb2.ExceptionInfo.FromString,
                )
        self.getRetainedReferences = channel.unary_unary(
                '/protos.dataservice.DataService/getRetainedReferences',
                request_serializer=protos_dot_common__messages__pb2.EmptyMessage.SerializeToString,
                response_deserializer=protos_dot_dataservice__messages__pb2.GetRetainedReferencesResponse.FromString,
                )
        self.getNumObjects = channel.unary_unary(
                '/protos.dataservice.DataService/getNumObjects',
                request_serializer=protos_dot_common__messages__pb2.EmptyMessage.SerializeToString,
                response_deserializer=protos_dot_common__messages__pb2.GetNumObjectsResponse.FromString,
                )
        self.getNumObjectsInEE = channel.unary_unary(
                '/protos.dataservice.DataService/getNumObjectsInEE',
                request_serializer=protos_dot_common__messages__pb2.EmptyMessage.SerializeToString,
                response_deserializer=protos_dot_common__messages__pb2.GetNumObjectsResponse.FromString,
                )
        self.getObjectGraph = channel.unary_unary(
                '/protos.dataservice.DataService/getObjectGraph',
                request_serializer=protos_dot_common__messages__pb2.EmptyMessage.SerializeToString,
                response_deserializer=protos_dot_dataservice__messages__pb2.GetObjectGraphResponse.FromString,
                )
        self.MakePersistent = channel.unary_unary(
                '/protos.dataservice.DataService/MakePersistent',
                request_serializer=protos_dot_dataservice__pb2.MakePersistentRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.CallActiveMethod = channel.unary_unary(
                '/protos.dataservice.DataService/CallActiveMethod',
                request_serializer=protos_dot_dataservice__pb2.CallActiveMethodRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_wrappers__pb2.BytesValue.FromString,
                )


class DataServiceServicer(object):
    """Interface exported by the server.
    """

    def initBackendID(self, request, context):
        """Deployment
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def associateExecutionEnvironment(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def deployMetaClasses(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def deployClasses(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def enrichClass(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def newPersistentInstance(self, request, context):
        """Execution Environment
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def storeObjects(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getCopyOfObject(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def updateObject(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getObjects(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def newVersion(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def consolidateVersion(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def upsertObjects(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def newReplica(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def moveObjects(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def removeObjects(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def migrateObjectsToBackends(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getClassIDFromObjectInMemory(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def executeImplementation(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def makePersistent(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def federate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def unfederate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def notifyFederation(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def notifyUnfederation(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def exists(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def synchronize(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def storeToDB(self, request, context):
        """Storage Location
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getFromDB(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def updateToDB(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def deleteToDB(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def deleteSetFromDB(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def existsInDB(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def cleanExecutionClassDirectory(self, request, context):
        """Others
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def closeDbHandler(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def shutDown(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def disconnectFromOthers(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def registerPendingObjects(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def cleanCaches(self, request, context):
        """Paraver
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def activateTracing(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def deactivateTracing(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getTraces(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def deleteAlias(self, request, context):
        """Garbage collection
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def detachObjectFromSession(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def closeSessionInDS(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getRetainedReferences(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getNumObjects(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getNumObjectsInEE(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getObjectGraph(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def MakePersistent(self, request, context):
        """NEW
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CallActiveMethod(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_DataServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'initBackendID': grpc.unary_unary_rpc_method_handler(
                    servicer.initBackendID,
                    request_deserializer=protos_dot_dataservice__messages__pb2.InitBackendIDRequest.FromString,
                    response_serializer=protos_dot_common__messages__pb2.ExceptionInfo.SerializeToString,
            ),
            'associateExecutionEnvironment': grpc.unary_unary_rpc_method_handler(
                    servicer.associateExecutionEnvironment,
                    request_deserializer=protos_dot_dataservice__messages__pb2.AssociateExecutionEnvironmentRequest.FromString,
                    response_serializer=protos_dot_common__messages__pb2.ExceptionInfo.SerializeToString,
            ),
            'deployMetaClasses': grpc.unary_unary_rpc_method_handler(
                    servicer.deployMetaClasses,
                    request_deserializer=protos_dot_dataservice__messages__pb2.DeployMetaClassesRequest.FromString,
                    response_serializer=protos_dot_common__messages__pb2.ExceptionInfo.SerializeToString,
            ),
            'deployClasses': grpc.unary_unary_rpc_method_handler(
                    servicer.deployClasses,
                    request_deserializer=protos_dot_dataservice__messages__pb2.DeployClassesRequest.FromString,
                    response_serializer=protos_dot_common__messages__pb2.ExceptionInfo.SerializeToString,
            ),
            'enrichClass': grpc.unary_unary_rpc_method_handler(
                    servicer.enrichClass,
                    request_deserializer=protos_dot_dataservice__messages__pb2.EnrichClassRequest.FromString,
                    response_serializer=protos_dot_common__messages__pb2.ExceptionInfo.SerializeToString,
            ),
            'newPersistentInstance': grpc.unary_unary_rpc_method_handler(
                    servicer.newPersistentInstance,
                    request_deserializer=protos_dot_dataservice__messages__pb2.NewPersistentInstanceRequest.FromString,
                    response_serializer=protos_dot_dataservice__messages__pb2.NewPersistentInstanceResponse.SerializeToString,
            ),
            'storeObjects': grpc.unary_unary_rpc_method_handler(
                    servicer.storeObjects,
                    request_deserializer=protos_dot_dataservice__messages__pb2.StoreObjectsRequest.FromString,
                    response_serializer=protos_dot_common__messages__pb2.ExceptionInfo.SerializeToString,
            ),
            'getCopyOfObject': grpc.unary_unary_rpc_method_handler(
                    servicer.getCopyOfObject,
                    request_deserializer=protos_dot_dataservice__messages__pb2.GetCopyOfObjectRequest.FromString,
                    response_serializer=protos_dot_dataservice__messages__pb2.GetCopyOfObjectResponse.SerializeToString,
            ),
            'updateObject': grpc.unary_unary_rpc_method_handler(
                    servicer.updateObject,
                    request_deserializer=protos_dot_dataservice__messages__pb2.UpdateObjectRequest.FromString,
                    response_serializer=protos_dot_common__messages__pb2.ExceptionInfo.SerializeToString,
            ),
            'getObjects': grpc.unary_unary_rpc_method_handler(
                    servicer.getObjects,
                    request_deserializer=protos_dot_dataservice__messages__pb2.GetObjectsRequest.FromString,
                    response_serializer=protos_dot_dataservice__messages__pb2.GetObjectsResponse.SerializeToString,
            ),
            'newVersion': grpc.unary_unary_rpc_method_handler(
                    servicer.newVersion,
                    request_deserializer=protos_dot_dataservice__messages__pb2.NewVersionRequest.FromString,
                    response_serializer=protos_dot_dataservice__messages__pb2.NewVersionResponse.SerializeToString,
            ),
            'consolidateVersion': grpc.unary_unary_rpc_method_handler(
                    servicer.consolidateVersion,
                    request_deserializer=protos_dot_dataservice__messages__pb2.ConsolidateVersionRequest.FromString,
                    response_serializer=protos_dot_common__messages__pb2.ExceptionInfo.SerializeToString,
            ),
            'upsertObjects': grpc.unary_unary_rpc_method_handler(
                    servicer.upsertObjects,
                    request_deserializer=protos_dot_dataservice__messages__pb2.UpsertObjectsRequest.FromString,
                    response_serializer=protos_dot_common__messages__pb2.ExceptionInfo.SerializeToString,
            ),
            'newReplica': grpc.unary_unary_rpc_method_handler(
                    servicer.newReplica,
                    request_deserializer=protos_dot_dataservice__messages__pb2.NewReplicaRequest.FromString,
                    response_serializer=protos_dot_dataservice__messages__pb2.NewReplicaResponse.SerializeToString,
            ),
            'moveObjects': grpc.unary_unary_rpc_method_handler(
                    servicer.moveObjects,
                    request_deserializer=protos_dot_dataservice__messages__pb2.MoveObjectsRequest.FromString,
                    response_serializer=protos_dot_dataservice__messages__pb2.MoveObjectsResponse.SerializeToString,
            ),
            'removeObjects': grpc.unary_unary_rpc_method_handler(
                    servicer.removeObjects,
                    request_deserializer=protos_dot_dataservice__messages__pb2.RemoveObjectsRequest.FromString,
                    response_serializer=protos_dot_dataservice__messages__pb2.RemoveObjectsResponse.SerializeToString,
            ),
            'migrateObjectsToBackends': grpc.unary_unary_rpc_method_handler(
                    servicer.migrateObjectsToBackends,
                    request_deserializer=protos_dot_dataservice__messages__pb2.MigrateObjectsRequest.FromString,
                    response_serializer=protos_dot_dataservice__messages__pb2.MigrateObjectsResponse.SerializeToString,
            ),
            'getClassIDFromObjectInMemory': grpc.unary_unary_rpc_method_handler(
                    servicer.getClassIDFromObjectInMemory,
                    request_deserializer=protos_dot_dataservice__messages__pb2.GetClassIDFromObjectInMemoryRequest.FromString,
                    response_serializer=protos_dot_dataservice__messages__pb2.GetClassIDFromObjectInMemoryResponse.SerializeToString,
            ),
            'executeImplementation': grpc.unary_unary_rpc_method_handler(
                    servicer.executeImplementation,
                    request_deserializer=protos_dot_dataservice__messages__pb2.ExecuteImplementationRequest.FromString,
                    response_serializer=protos_dot_dataservice__messages__pb2.ExecuteImplementationResponse.SerializeToString,
            ),
            'makePersistent': grpc.unary_unary_rpc_method_handler(
                    servicer.makePersistent,
                    request_deserializer=protos_dot_dataservice__messages__pb2.OldMakePersistentRequest.FromString,
                    response_serializer=protos_dot_common__messages__pb2.ExceptionInfo.SerializeToString,
            ),
            'federate': grpc.unary_unary_rpc_method_handler(
                    servicer.federate,
                    request_deserializer=protos_dot_dataservice__messages__pb2.FederateRequest.FromString,
                    response_serializer=protos_dot_common__messages__pb2.ExceptionInfo.SerializeToString,
            ),
            'unfederate': grpc.unary_unary_rpc_method_handler(
                    servicer.unfederate,
                    request_deserializer=protos_dot_dataservice__messages__pb2.UnfederateRequest.FromString,
                    response_serializer=protos_dot_common__messages__pb2.ExceptionInfo.SerializeToString,
            ),
            'notifyFederation': grpc.unary_unary_rpc_method_handler(
                    servicer.notifyFederation,
                    request_deserializer=protos_dot_dataservice__messages__pb2.NotifyFederationRequest.FromString,
                    response_serializer=protos_dot_common__messages__pb2.ExceptionInfo.SerializeToString,
            ),
            'notifyUnfederation': grpc.unary_unary_rpc_method_handler(
                    servicer.notifyUnfederation,
                    request_deserializer=protos_dot_dataservice__messages__pb2.NotifyUnfederationRequest.FromString,
                    response_serializer=protos_dot_common__messages__pb2.ExceptionInfo.SerializeToString,
            ),
            'exists': grpc.unary_unary_rpc_method_handler(
                    servicer.exists,
                    request_deserializer=protos_dot_dataservice__messages__pb2.ExistsRequest.FromString,
                    response_serializer=protos_dot_dataservice__messages__pb2.ExistsResponse.SerializeToString,
            ),
            'synchronize': grpc.unary_unary_rpc_method_handler(
                    servicer.synchronize,
                    request_deserializer=protos_dot_dataservice__messages__pb2.SynchronizeRequest.FromString,
                    response_serializer=protos_dot_common__messages__pb2.ExceptionInfo.SerializeToString,
            ),
            'storeToDB': grpc.unary_unary_rpc_method_handler(
                    servicer.storeToDB,
                    request_deserializer=protos_dot_dataservice__messages__pb2.StoreToDBRequest.FromString,
                    response_serializer=protos_dot_common__messages__pb2.ExceptionInfo.SerializeToString,
            ),
            'getFromDB': grpc.unary_unary_rpc_method_handler(
                    servicer.getFromDB,
                    request_deserializer=protos_dot_dataservice__messages__pb2.GetFromDBRequest.FromString,
                    response_serializer=protos_dot_dataservice__messages__pb2.GetFromDBResponse.SerializeToString,
            ),
            'updateToDB': grpc.unary_unary_rpc_method_handler(
                    servicer.updateToDB,
                    request_deserializer=protos_dot_dataservice__messages__pb2.UpdateToDBRequest.FromString,
                    response_serializer=protos_dot_common__messages__pb2.ExceptionInfo.SerializeToString,
            ),
            'deleteToDB': grpc.unary_unary_rpc_method_handler(
                    servicer.deleteToDB,
                    request_deserializer=protos_dot_dataservice__messages__pb2.DeleteToDBRequest.FromString,
                    response_serializer=protos_dot_common__messages__pb2.ExceptionInfo.SerializeToString,
            ),
            'deleteSetFromDB': grpc.unary_unary_rpc_method_handler(
                    servicer.deleteSetFromDB,
                    request_deserializer=protos_dot_dataservice__messages__pb2.DeleteSetFromDBRequest.FromString,
                    response_serializer=protos_dot_common__messages__pb2.ExceptionInfo.SerializeToString,
            ),
            'existsInDB': grpc.unary_unary_rpc_method_handler(
                    servicer.existsInDB,
                    request_deserializer=protos_dot_dataservice__messages__pb2.ExistsInDBRequest.FromString,
                    response_serializer=protos_dot_dataservice__messages__pb2.ExistsInDBResponse.SerializeToString,
            ),
            'cleanExecutionClassDirectory': grpc.unary_unary_rpc_method_handler(
                    servicer.cleanExecutionClassDirectory,
                    request_deserializer=protos_dot_common__messages__pb2.EmptyMessage.FromString,
                    response_serializer=protos_dot_common__messages__pb2.ExceptionInfo.SerializeToString,
            ),
            'closeDbHandler': grpc.unary_unary_rpc_method_handler(
                    servicer.closeDbHandler,
                    request_deserializer=protos_dot_common__messages__pb2.EmptyMessage.FromString,
                    response_serializer=protos_dot_common__messages__pb2.ExceptionInfo.SerializeToString,
            ),
            'shutDown': grpc.unary_unary_rpc_method_handler(
                    servicer.shutDown,
                    request_deserializer=protos_dot_common__messages__pb2.EmptyMessage.FromString,
                    response_serializer=protos_dot_common__messages__pb2.ExceptionInfo.SerializeToString,
            ),
            'disconnectFromOthers': grpc.unary_unary_rpc_method_handler(
                    servicer.disconnectFromOthers,
                    request_deserializer=protos_dot_common__messages__pb2.EmptyMessage.FromString,
                    response_serializer=protos_dot_common__messages__pb2.ExceptionInfo.SerializeToString,
            ),
            'registerPendingObjects': grpc.unary_unary_rpc_method_handler(
                    servicer.registerPendingObjects,
                    request_deserializer=protos_dot_common__messages__pb2.EmptyMessage.FromString,
                    response_serializer=protos_dot_common__messages__pb2.ExceptionInfo.SerializeToString,
            ),
            'cleanCaches': grpc.unary_unary_rpc_method_handler(
                    servicer.cleanCaches,
                    request_deserializer=protos_dot_common__messages__pb2.EmptyMessage.FromString,
                    response_serializer=protos_dot_common__messages__pb2.ExceptionInfo.SerializeToString,
            ),
            'activateTracing': grpc.unary_unary_rpc_method_handler(
                    servicer.activateTracing,
                    request_deserializer=protos_dot_dataservice__messages__pb2.ActivateTracingRequest.FromString,
                    response_serializer=protos_dot_common__messages__pb2.ExceptionInfo.SerializeToString,
            ),
            'deactivateTracing': grpc.unary_unary_rpc_method_handler(
                    servicer.deactivateTracing,
                    request_deserializer=protos_dot_common__messages__pb2.EmptyMessage.FromString,
                    response_serializer=protos_dot_common__messages__pb2.ExceptionInfo.SerializeToString,
            ),
            'getTraces': grpc.unary_unary_rpc_method_handler(
                    servicer.getTraces,
                    request_deserializer=protos_dot_common__messages__pb2.EmptyMessage.FromString,
                    response_serializer=protos_dot_common__messages__pb2.GetTracesResponse.SerializeToString,
            ),
            'deleteAlias': grpc.unary_unary_rpc_method_handler(
                    servicer.deleteAlias,
                    request_deserializer=protos_dot_dataservice__messages__pb2.DeleteAliasRequest.FromString,
                    response_serializer=protos_dot_common__messages__pb2.ExceptionInfo.SerializeToString,
            ),
            'detachObjectFromSession': grpc.unary_unary_rpc_method_handler(
                    servicer.detachObjectFromSession,
                    request_deserializer=protos_dot_dataservice__messages__pb2.DetachObjectFromSessionRequest.FromString,
                    response_serializer=protos_dot_common__messages__pb2.ExceptionInfo.SerializeToString,
            ),
            'closeSessionInDS': grpc.unary_unary_rpc_method_handler(
                    servicer.closeSessionInDS,
                    request_deserializer=protos_dot_dataservice__messages__pb2.CloseSessionInDSRequest.FromString,
                    response_serializer=protos_dot_common__messages__pb2.ExceptionInfo.SerializeToString,
            ),
            'getRetainedReferences': grpc.unary_unary_rpc_method_handler(
                    servicer.getRetainedReferences,
                    request_deserializer=protos_dot_common__messages__pb2.EmptyMessage.FromString,
                    response_serializer=protos_dot_dataservice__messages__pb2.GetRetainedReferencesResponse.SerializeToString,
            ),
            'getNumObjects': grpc.unary_unary_rpc_method_handler(
                    servicer.getNumObjects,
                    request_deserializer=protos_dot_common__messages__pb2.EmptyMessage.FromString,
                    response_serializer=protos_dot_common__messages__pb2.GetNumObjectsResponse.SerializeToString,
            ),
            'getNumObjectsInEE': grpc.unary_unary_rpc_method_handler(
                    servicer.getNumObjectsInEE,
                    request_deserializer=protos_dot_common__messages__pb2.EmptyMessage.FromString,
                    response_serializer=protos_dot_common__messages__pb2.GetNumObjectsResponse.SerializeToString,
            ),
            'getObjectGraph': grpc.unary_unary_rpc_method_handler(
                    servicer.getObjectGraph,
                    request_deserializer=protos_dot_common__messages__pb2.EmptyMessage.FromString,
                    response_serializer=protos_dot_dataservice__messages__pb2.GetObjectGraphResponse.SerializeToString,
            ),
            'MakePersistent': grpc.unary_unary_rpc_method_handler(
                    servicer.MakePersistent,
                    request_deserializer=protos_dot_dataservice__pb2.MakePersistentRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'CallActiveMethod': grpc.unary_unary_rpc_method_handler(
                    servicer.CallActiveMethod,
                    request_deserializer=protos_dot_dataservice__pb2.CallActiveMethodRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_wrappers__pb2.BytesValue.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'protos.dataservice.DataService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class DataService(object):
    """Interface exported by the server.
    """

    @staticmethod
    def initBackendID(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.dataservice.DataService/initBackendID',
            protos_dot_dataservice__messages__pb2.InitBackendIDRequest.SerializeToString,
            protos_dot_common__messages__pb2.ExceptionInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def associateExecutionEnvironment(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.dataservice.DataService/associateExecutionEnvironment',
            protos_dot_dataservice__messages__pb2.AssociateExecutionEnvironmentRequest.SerializeToString,
            protos_dot_common__messages__pb2.ExceptionInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def deployMetaClasses(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.dataservice.DataService/deployMetaClasses',
            protos_dot_dataservice__messages__pb2.DeployMetaClassesRequest.SerializeToString,
            protos_dot_common__messages__pb2.ExceptionInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def deployClasses(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.dataservice.DataService/deployClasses',
            protos_dot_dataservice__messages__pb2.DeployClassesRequest.SerializeToString,
            protos_dot_common__messages__pb2.ExceptionInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def enrichClass(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.dataservice.DataService/enrichClass',
            protos_dot_dataservice__messages__pb2.EnrichClassRequest.SerializeToString,
            protos_dot_common__messages__pb2.ExceptionInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def newPersistentInstance(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.dataservice.DataService/newPersistentInstance',
            protos_dot_dataservice__messages__pb2.NewPersistentInstanceRequest.SerializeToString,
            protos_dot_dataservice__messages__pb2.NewPersistentInstanceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def storeObjects(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.dataservice.DataService/storeObjects',
            protos_dot_dataservice__messages__pb2.StoreObjectsRequest.SerializeToString,
            protos_dot_common__messages__pb2.ExceptionInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def getCopyOfObject(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.dataservice.DataService/getCopyOfObject',
            protos_dot_dataservice__messages__pb2.GetCopyOfObjectRequest.SerializeToString,
            protos_dot_dataservice__messages__pb2.GetCopyOfObjectResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def updateObject(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.dataservice.DataService/updateObject',
            protos_dot_dataservice__messages__pb2.UpdateObjectRequest.SerializeToString,
            protos_dot_common__messages__pb2.ExceptionInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def getObjects(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.dataservice.DataService/getObjects',
            protos_dot_dataservice__messages__pb2.GetObjectsRequest.SerializeToString,
            protos_dot_dataservice__messages__pb2.GetObjectsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def newVersion(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.dataservice.DataService/newVersion',
            protos_dot_dataservice__messages__pb2.NewVersionRequest.SerializeToString,
            protos_dot_dataservice__messages__pb2.NewVersionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def consolidateVersion(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.dataservice.DataService/consolidateVersion',
            protos_dot_dataservice__messages__pb2.ConsolidateVersionRequest.SerializeToString,
            protos_dot_common__messages__pb2.ExceptionInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def upsertObjects(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.dataservice.DataService/upsertObjects',
            protos_dot_dataservice__messages__pb2.UpsertObjectsRequest.SerializeToString,
            protos_dot_common__messages__pb2.ExceptionInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def newReplica(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.dataservice.DataService/newReplica',
            protos_dot_dataservice__messages__pb2.NewReplicaRequest.SerializeToString,
            protos_dot_dataservice__messages__pb2.NewReplicaResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def moveObjects(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.dataservice.DataService/moveObjects',
            protos_dot_dataservice__messages__pb2.MoveObjectsRequest.SerializeToString,
            protos_dot_dataservice__messages__pb2.MoveObjectsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def removeObjects(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.dataservice.DataService/removeObjects',
            protos_dot_dataservice__messages__pb2.RemoveObjectsRequest.SerializeToString,
            protos_dot_dataservice__messages__pb2.RemoveObjectsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def migrateObjectsToBackends(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.dataservice.DataService/migrateObjectsToBackends',
            protos_dot_dataservice__messages__pb2.MigrateObjectsRequest.SerializeToString,
            protos_dot_dataservice__messages__pb2.MigrateObjectsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def getClassIDFromObjectInMemory(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.dataservice.DataService/getClassIDFromObjectInMemory',
            protos_dot_dataservice__messages__pb2.GetClassIDFromObjectInMemoryRequest.SerializeToString,
            protos_dot_dataservice__messages__pb2.GetClassIDFromObjectInMemoryResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def executeImplementation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.dataservice.DataService/executeImplementation',
            protos_dot_dataservice__messages__pb2.ExecuteImplementationRequest.SerializeToString,
            protos_dot_dataservice__messages__pb2.ExecuteImplementationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def makePersistent(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.dataservice.DataService/makePersistent',
            protos_dot_dataservice__messages__pb2.OldMakePersistentRequest.SerializeToString,
            protos_dot_common__messages__pb2.ExceptionInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def federate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.dataservice.DataService/federate',
            protos_dot_dataservice__messages__pb2.FederateRequest.SerializeToString,
            protos_dot_common__messages__pb2.ExceptionInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def unfederate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.dataservice.DataService/unfederate',
            protos_dot_dataservice__messages__pb2.UnfederateRequest.SerializeToString,
            protos_dot_common__messages__pb2.ExceptionInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def notifyFederation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.dataservice.DataService/notifyFederation',
            protos_dot_dataservice__messages__pb2.NotifyFederationRequest.SerializeToString,
            protos_dot_common__messages__pb2.ExceptionInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def notifyUnfederation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.dataservice.DataService/notifyUnfederation',
            protos_dot_dataservice__messages__pb2.NotifyUnfederationRequest.SerializeToString,
            protos_dot_common__messages__pb2.ExceptionInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def exists(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.dataservice.DataService/exists',
            protos_dot_dataservice__messages__pb2.ExistsRequest.SerializeToString,
            protos_dot_dataservice__messages__pb2.ExistsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def synchronize(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.dataservice.DataService/synchronize',
            protos_dot_dataservice__messages__pb2.SynchronizeRequest.SerializeToString,
            protos_dot_common__messages__pb2.ExceptionInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def storeToDB(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.dataservice.DataService/storeToDB',
            protos_dot_dataservice__messages__pb2.StoreToDBRequest.SerializeToString,
            protos_dot_common__messages__pb2.ExceptionInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def getFromDB(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.dataservice.DataService/getFromDB',
            protos_dot_dataservice__messages__pb2.GetFromDBRequest.SerializeToString,
            protos_dot_dataservice__messages__pb2.GetFromDBResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def updateToDB(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.dataservice.DataService/updateToDB',
            protos_dot_dataservice__messages__pb2.UpdateToDBRequest.SerializeToString,
            protos_dot_common__messages__pb2.ExceptionInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def deleteToDB(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.dataservice.DataService/deleteToDB',
            protos_dot_dataservice__messages__pb2.DeleteToDBRequest.SerializeToString,
            protos_dot_common__messages__pb2.ExceptionInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def deleteSetFromDB(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.dataservice.DataService/deleteSetFromDB',
            protos_dot_dataservice__messages__pb2.DeleteSetFromDBRequest.SerializeToString,
            protos_dot_common__messages__pb2.ExceptionInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def existsInDB(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.dataservice.DataService/existsInDB',
            protos_dot_dataservice__messages__pb2.ExistsInDBRequest.SerializeToString,
            protos_dot_dataservice__messages__pb2.ExistsInDBResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def cleanExecutionClassDirectory(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.dataservice.DataService/cleanExecutionClassDirectory',
            protos_dot_common__messages__pb2.EmptyMessage.SerializeToString,
            protos_dot_common__messages__pb2.ExceptionInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def closeDbHandler(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.dataservice.DataService/closeDbHandler',
            protos_dot_common__messages__pb2.EmptyMessage.SerializeToString,
            protos_dot_common__messages__pb2.ExceptionInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def shutDown(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.dataservice.DataService/shutDown',
            protos_dot_common__messages__pb2.EmptyMessage.SerializeToString,
            protos_dot_common__messages__pb2.ExceptionInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def disconnectFromOthers(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.dataservice.DataService/disconnectFromOthers',
            protos_dot_common__messages__pb2.EmptyMessage.SerializeToString,
            protos_dot_common__messages__pb2.ExceptionInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def registerPendingObjects(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.dataservice.DataService/registerPendingObjects',
            protos_dot_common__messages__pb2.EmptyMessage.SerializeToString,
            protos_dot_common__messages__pb2.ExceptionInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def cleanCaches(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.dataservice.DataService/cleanCaches',
            protos_dot_common__messages__pb2.EmptyMessage.SerializeToString,
            protos_dot_common__messages__pb2.ExceptionInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def activateTracing(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.dataservice.DataService/activateTracing',
            protos_dot_dataservice__messages__pb2.ActivateTracingRequest.SerializeToString,
            protos_dot_common__messages__pb2.ExceptionInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def deactivateTracing(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.dataservice.DataService/deactivateTracing',
            protos_dot_common__messages__pb2.EmptyMessage.SerializeToString,
            protos_dot_common__messages__pb2.ExceptionInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def getTraces(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.dataservice.DataService/getTraces',
            protos_dot_common__messages__pb2.EmptyMessage.SerializeToString,
            protos_dot_common__messages__pb2.GetTracesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def deleteAlias(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.dataservice.DataService/deleteAlias',
            protos_dot_dataservice__messages__pb2.DeleteAliasRequest.SerializeToString,
            protos_dot_common__messages__pb2.ExceptionInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def detachObjectFromSession(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.dataservice.DataService/detachObjectFromSession',
            protos_dot_dataservice__messages__pb2.DetachObjectFromSessionRequest.SerializeToString,
            protos_dot_common__messages__pb2.ExceptionInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def closeSessionInDS(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.dataservice.DataService/closeSessionInDS',
            protos_dot_dataservice__messages__pb2.CloseSessionInDSRequest.SerializeToString,
            protos_dot_common__messages__pb2.ExceptionInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def getRetainedReferences(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.dataservice.DataService/getRetainedReferences',
            protos_dot_common__messages__pb2.EmptyMessage.SerializeToString,
            protos_dot_dataservice__messages__pb2.GetRetainedReferencesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def getNumObjects(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.dataservice.DataService/getNumObjects',
            protos_dot_common__messages__pb2.EmptyMessage.SerializeToString,
            protos_dot_common__messages__pb2.GetNumObjectsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def getNumObjectsInEE(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.dataservice.DataService/getNumObjectsInEE',
            protos_dot_common__messages__pb2.EmptyMessage.SerializeToString,
            protos_dot_common__messages__pb2.GetNumObjectsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def getObjectGraph(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.dataservice.DataService/getObjectGraph',
            protos_dot_common__messages__pb2.EmptyMessage.SerializeToString,
            protos_dot_dataservice__messages__pb2.GetObjectGraphResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def MakePersistent(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.dataservice.DataService/MakePersistent',
            protos_dot_dataservice__pb2.MakePersistentRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CallActiveMethod(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.dataservice.DataService/CallActiveMethod',
            protos_dot_dataservice__pb2.CallActiveMethodRequest.SerializeToString,
            google_dot_protobuf_dot_wrappers__pb2.BytesValue.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from . import common_messages_pb2 as protos_dot_common__messages__pb2
from . import metadata_service_pb2 as protos_dot_metadata__service__pb2


class MetadataServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.NewAccount = channel.unary_unary(
                '/protos.metadata_service.MetadataService/NewAccount',
                request_serializer=protos_dot_metadata__service__pb2.NewAccountRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.GetAccount = channel.unary_unary(
                '/protos.metadata_service.MetadataService/GetAccount',
                request_serializer=protos_dot_metadata__service__pb2.GetAccountRequest.SerializeToString,
                response_deserializer=protos_dot_metadata__service__pb2.GetAccountResponse.FromString,
                )
        self.NewSession = channel.unary_unary(
                '/protos.metadata_service.MetadataService/NewSession',
                request_serializer=protos_dot_metadata__service__pb2.NewSessionRequest.SerializeToString,
                response_deserializer=protos_dot_common__messages__pb2.Session.FromString,
                )
        self.CloseSession = channel.unary_unary(
                '/protos.metadata_service.MetadataService/CloseSession',
                request_serializer=protos_dot_metadata__service__pb2.CloseSessionRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.NewDataset = channel.unary_unary(
                '/protos.metadata_service.MetadataService/NewDataset',
                request_serializer=protos_dot_metadata__service__pb2.NewDatasetRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.GetAllExecutionEnvironments = channel.unary_unary(
                '/protos.metadata_service.MetadataService/GetAllExecutionEnvironments',
                request_serializer=protos_dot_metadata__service__pb2.GetAllExecutionEnvironmentsRequest.SerializeToString,
                response_deserializer=protos_dot_metadata__service__pb2.GetAllExecutionEnvironmentsResponse.FromString,
                )
        self.GetDataclayID = channel.unary_unary(
                '/protos.metadata_service.MetadataService/GetDataclayID',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=protos_dot_metadata__service__pb2.GetDataclayIDResponse.FromString,
                )
        self.AutoregisterEE = channel.unary_unary(
                '/protos.metadata_service.MetadataService/AutoregisterEE',
                request_serializer=protos_dot_metadata__service__pb2.AutoRegisterEERequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.RegisterObject = channel.unary_unary(
                '/protos.metadata_service.MetadataService/RegisterObject',
                request_serializer=protos_dot_metadata__service__pb2.RegisterObjectRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.GetObjectMDById = channel.unary_unary(
                '/protos.metadata_service.MetadataService/GetObjectMDById',
                request_serializer=protos_dot_metadata__service__pb2.GetObjectMDByIdRequest.SerializeToString,
                response_deserializer=protos_dot_common__messages__pb2.ObjectMetadata.FromString,
                )
        self.GetObjectMDByAlias = channel.unary_unary(
                '/protos.metadata_service.MetadataService/GetObjectMDByAlias',
                request_serializer=protos_dot_metadata__service__pb2.GetObjectMDByAliasRequest.SerializeToString,
                response_deserializer=protos_dot_common__messages__pb2.ObjectMetadata.FromString,
                )
        self.DeleteAlias = channel.unary_unary(
                '/protos.metadata_service.MetadataService/DeleteAlias',
                request_serializer=protos_dot_metadata__service__pb2.DeleteAliasRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )


class MetadataServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def NewAccount(self, request, context):
        """Account Manager
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAccount(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def NewSession(self, request, context):
        """Session Manager
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CloseSession(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def NewDataset(self, request, context):
        """Dataset Manager
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAllExecutionEnvironments(self, request, context):
        """EE-SL information
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDataclayID(self, request, context):
        """Federation
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AutoregisterEE(self, request, context):
        """Autoregister
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RegisterObject(self, request, context):
        """Object Metadata
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetObjectMDById(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetObjectMDByAlias(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteAlias(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_MetadataServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'NewAccount': grpc.unary_unary_rpc_method_handler(
                    servicer.NewAccount,
                    request_deserializer=protos_dot_metadata__service__pb2.NewAccountRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'GetAccount': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAccount,
                    request_deserializer=protos_dot_metadata__service__pb2.GetAccountRequest.FromString,
                    response_serializer=protos_dot_metadata__service__pb2.GetAccountResponse.SerializeToString,
            ),
            'NewSession': grpc.unary_unary_rpc_method_handler(
                    servicer.NewSession,
                    request_deserializer=protos_dot_metadata__service__pb2.NewSessionRequest.FromString,
                    response_serializer=protos_dot_common__messages__pb2.Session.SerializeToString,
            ),
            'CloseSession': grpc.unary_unary_rpc_method_handler(
                    servicer.CloseSession,
                    request_deserializer=protos_dot_metadata__service__pb2.CloseSessionRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'NewDataset': grpc.unary_unary_rpc_method_handler(
                    servicer.NewDataset,
                    request_deserializer=protos_dot_metadata__service__pb2.NewDatasetRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'GetAllExecutionEnvironments': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAllExecutionEnvironments,
                    request_deserializer=protos_dot_metadata__service__pb2.GetAllExecutionEnvironmentsRequest.FromString,
                    response_serializer=protos_dot_metadata__service__pb2.GetAllExecutionEnvironmentsResponse.SerializeToString,
            ),
            'GetDataclayID': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDataclayID,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=protos_dot_metadata__service__pb2.GetDataclayIDResponse.SerializeToString,
            ),
            'AutoregisterEE': grpc.unary_unary_rpc_method_handler(
                    servicer.AutoregisterEE,
                    request_deserializer=protos_dot_metadata__service__pb2.AutoRegisterEERequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'RegisterObject': grpc.unary_unary_rpc_method_handler(
                    servicer.RegisterObject,
                    request_deserializer=protos_dot_metadata__service__pb2.RegisterObjectRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'GetObjectMDById': grpc.unary_unary_rpc_method_handler(
                    servicer.GetObjectMDById,
                    request_deserializer=protos_dot_metadata__service__pb2.GetObjectMDByIdRequest.FromString,
                    response_serializer=protos_dot_common__messages__pb2.ObjectMetadata.SerializeToString,
            ),
            'GetObjectMDByAlias': grpc.unary_unary_rpc_method_handler(
                    servicer.GetObjectMDByAlias,
                    request_deserializer=protos_dot_metadata__service__pb2.GetObjectMDByAliasRequest.FromString,
                    response_serializer=protos_dot_common__messages__pb2.ObjectMetadata.SerializeToString,
            ),
            'DeleteAlias': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteAlias,
                    request_deserializer=protos_dot_metadata__service__pb2.DeleteAliasRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'protos.metadata_service.MetadataService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class MetadataService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def NewAccount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.metadata_service.MetadataService/NewAccount',
            protos_dot_metadata__service__pb2.NewAccountRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetAccount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.metadata_service.MetadataService/GetAccount',
            protos_dot_metadata__service__pb2.GetAccountRequest.SerializeToString,
            protos_dot_metadata__service__pb2.GetAccountResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def NewSession(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.metadata_service.MetadataService/NewSession',
            protos_dot_metadata__service__pb2.NewSessionRequest.SerializeToString,
            protos_dot_common__messages__pb2.Session.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CloseSession(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.metadata_service.MetadataService/CloseSession',
            protos_dot_metadata__service__pb2.CloseSessionRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def NewDataset(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.metadata_service.MetadataService/NewDataset',
            protos_dot_metadata__service__pb2.NewDatasetRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetAllExecutionEnvironments(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.metadata_service.MetadataService/GetAllExecutionEnvironments',
            protos_dot_metadata__service__pb2.GetAllExecutionEnvironmentsRequest.SerializeToString,
            protos_dot_metadata__service__pb2.GetAllExecutionEnvironmentsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDataclayID(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.metadata_service.MetadataService/GetDataclayID',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            protos_dot_metadata__service__pb2.GetDataclayIDResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AutoregisterEE(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.metadata_service.MetadataService/AutoregisterEE',
            protos_dot_metadata__service__pb2.AutoRegisterEERequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RegisterObject(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.metadata_service.MetadataService/RegisterObject',
            protos_dot_metadata__service__pb2.RegisterObjectRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetObjectMDById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.metadata_service.MetadataService/GetObjectMDById',
            protos_dot_metadata__service__pb2.GetObjectMDByIdRequest.SerializeToString,
            protos_dot_common__messages__pb2.ObjectMetadata.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetObjectMDByAlias(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.metadata_service.MetadataService/GetObjectMDByAlias',
            protos_dot_metadata__service__pb2.GetObjectMDByAliasRequest.SerializeToString,
            protos_dot_common__messages__pb2.ObjectMetadata.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteAlias(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.metadata_service.MetadataService/DeleteAlias',
            protos_dot_metadata__service__pb2.DeleteAliasRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
